@@ -542,7 +542,7 @@ class AwsCdkConstructLibrary(
 
         jsii.create(self.__class__, self, [options])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="formatTask")
     def format_task(self) -> projen.Task:
         '''The "format" task.'''
